@@ -249,6 +249,9 @@ void set_error(const ignite::ignite_error &error) {
             error_class = py_get_module_database_error_class();
             break;
         }
+		
+		default:
+			break;
     }
 
     PyErr_SetString(error_class, error.what());
